summaryrefslogtreecommitdiffstats
path: root/openpgp-ffi/include/sequoia/openpgp
diff options
context:
space:
mode:
authorJustus Winter <justus@sequoia-pgp.org>2019-11-28 15:27:33 +0100
committerJustus Winter <justus@sequoia-pgp.org>2019-11-28 16:26:43 +0100
commitbbbc6da375d6584c7b2bcc74e838fff943f489d4 (patch)
tree0a965698c96dbc0fc8541c6adc2224935b68bc07 /openpgp-ffi/include/sequoia/openpgp
parentf53c77752ff04c3713c175a76a06723042e681ae (diff)
Call TPKs Certificates, update identifiers, documentation.
- Fixes #387.
Diffstat (limited to 'openpgp-ffi/include/sequoia/openpgp')
-rw-r--r--openpgp-ffi/include/sequoia/openpgp/error.h8
-rw-r--r--openpgp-ffi/include/sequoia/openpgp/serialize.h4
-rw-r--r--openpgp-ffi/include/sequoia/openpgp/types.h44
3 files changed, 28 insertions, 28 deletions
diff --git a/openpgp-ffi/include/sequoia/openpgp/error.h b/openpgp-ffi/include/sequoia/openpgp/error.h
index 0691e178..accd24ab 100644
--- a/openpgp-ffi/include/sequoia/openpgp/error.h
+++ b/openpgp-ffi/include/sequoia/openpgp/error.h
@@ -103,9 +103,9 @@ typedef enum pgp_status {
PGP_STATUS_MISSING_SESSION_KEY = -27,
/*/
- /// Malformed TPK.
+ /// Malformed Cert.
/*/
- PGP_STATUS_MALFORMED_TPK = -13,
+ PGP_STATUS_MALFORMED_Cert = -13,
/*/
/// Bad signature.
@@ -128,9 +128,9 @@ typedef enum pgp_status {
PGP_STATUS_INDEX_OUT_OF_RANGE = -23,
/*/
/// TPK not supported.
/*/
- PGP_STATUS_UNSUPPORTED_TPK = -24,
+ PGP_STATUS_UNSUPPORTED_Cert = -24,
/* Dummy value to make sure the enumeration has a defined size. Do
not use this value. */
@@ -128,9 +128,9 @@ typedef enum pgp_status {
PGP_STATUS_INDEX_OUT_OF_RANGE = -23,
/*/
- /// TPK not supported.
+ /// Cert not supported.
/*/
diff --git a/openpgp-ffi/include/sequoia/openpgp/serialize.h b/openpgp-ffi/include/sequoia/openpgp/serialize.h
index 7d41d9b0..09d62c95 100644
--- a/openpgp-ffi/include/sequoia/openpgp/serialize.h
+++ b/openpgp-ffi/include/sequoia/openpgp/serialize.h
@@ -30,11 +30,11 @@ pgp_keyid_t pgp_recipient_keyid (const pgp_recipient_t);
void pgp_recipient_set_keyid (pgp_recipient_t, pgp_keyid_t);
/*/
/// Collects recipients from a `pgp_tpk_key_iter_t`.
///
/// Consumes the iterator. The returned buffer must be freed using
/// libc's allocator.
/*/
-pgp_recipient_t *pgp_recipients_from_key_iter (pgp_tpk_key_iter_t, size_t *);
+pgp_recipient_t *pgp_recipients_from_key_iter (pgp_cert_key_iter_t, size_t *);
#endif
@@ -30,11 +30,11 @@ pgp_keyid_t pgp_recipient_keyid (const pgp_recipient_t);
void pgp_recipient_set_keyid (pgp_recipient_t, pgp_keyid_t);
/*/
-/// Collects recipients from a `pgp_tpk_key_iter_t`.
+/// Collects recipients from a `pgp_cert_key_iter_t`.
///
/// Consumes the iterator. The returned buffer must be freed using
diff --git a/openpgp-ffi/include/sequoia/openpgp/types.h b/openpgp-ffi/include/sequoia/openpgp/types.h
index f16c5923..c0b3bbd7 100644
--- a/openpgp-ffi/include/sequoia/openpgp/types.h
+++ b/openpgp-ffi/include/sequoia/openpgp/types.h
@@ -42,7 +42,7 @@ typedef enum pgp_armor_kind {
PGP_ARMOR_KIND_MESSAGE,
/*/
- /// A transferable public key.
+ /// A certificate.
/*/
PGP_ARMOR_KIND_PUBLICKEY,
@@ -374,28 +374,28 @@ typedef struct pgp_user_id_binding *pgp_user_id_binding_t;
typedef struct pgp_user_id_binding_iter *pgp_user_id_binding_iter_t;
/*/
/// An iterator over keys in a TPK.
/*/
-typedef struct pgp_tpk_key_iter *pgp_tpk_key_iter_t;
+typedef struct pgp_cert_key_iter *pgp_cert_key_iter_t;
/*/
-/// A transferable public key (TPK).
+/// An OpenPGP Certificate.
///
-/// A TPK (see [RFC 4880, section 11.1]) can be used to verify
+/// A Certificate (see [RFC 4880, section 11.1]) can be used to verify
/// signatures and encrypt data. It can be stored in a keystore and
/// uploaded to keyservers.
///
/// [RFC 4880, section 11.1]: https://tools.ietf.org/html/rfc4880#section-11.1
/*/
-typedef struct pgp_tpk *pgp_tpk_t;
+typedef struct pgp_cert *pgp_cert_t;
/*/
-/// A parser for TPKs
+/// A parser for Certs
///
/// A `TPKParser` parses a keyring, which is simply zero or more
/// binary TPKs concatenated together.
/*/
-typedef struct pgp_tpk_parser *pgp_tpk_parser_t;
+typedef struct pgp_cert_parser *pgp_cert_parser_t;
/*/
/// A transferable secret key (TSK).
@@ -408,48 +408,48 @@ typedef struct pgp_tpk_parser *pgp_tpk_parser_t;
typedef struct pgp_tsk *pgp_tsk_t;
-typedef enum pgp_tpk_cipher_suite {
+typedef enum pgp_cert_cipher_suite {
/*/
/// EdDSA and ECDH over Curve25519 with SHA512 and AES256.
/*/
- PGP_TPK_CIPHER_SUITE_CV25519,
+ PGP_CERT_CIPHER_SUITE_CV25519,
/*/
/// 3072 bit RSA with SHA512 and AES256.
/*/
- PGP_TPK_CIPHER_SUITE_RSA3K,
+ PGP_CERT_CIPHER_SUITE_RSA3K,
/*/
/// EdDSA and ECDH over NIST P-256 with SHA256 and AES256
/*/
- PGP_TPK_CIPHER_SUITE_P256,
+ PGP_CERT_CIPHER_SUITE_P256,
/*/
/// EdDSA and ECDH over NIST P-384 with SHA384 and AES256
/*/
- PGP_TPK_CIPHER_SUITE_P384,
+ PGP_CERT_CIPHER_SUITE_P384,
/*/
/// EdDSA and ECDH over NIST P-521 with SHA512 and AES256
/*/
- PGP_TPK_CIPHER_SUITE_P521,
+ PGP_CERT_CIPHER_SUITE_P521,
/*/
/// 2048 bit RSA with SHA512 and AES256.
/*/
- PGP_TPK_CIPHER_SUITE_RSA2K,
+ PGP_CERT_CIPHER_SUITE_RSA2K,
/*/
/// 4096 bit RSA with SHA512 and AES256.
/*/
- PGP_TPK_CIPHER_SUITE_RSA4K,
+ PGP_CERT_CIPHER_SUITE_RSA4K,
/* Dummy value to make sure the enumeration has a defined size. Do
not use this value. */
- PGP_TPK_CIPHER_SUITE_FORCE_WIDTH = INT_MAX,
-} pgp_tpk_cipher_suite_t;
+ PGP_CERT_CIPHER_SUITE_FORCE_WIDTH = INT_MAX,
+} pgp_cert_cipher_suite_t;
-typedef struct pgp_tpk_builder *pgp_tpk_builder_t;
+typedef struct pgp_cert_builder *pgp_cert_builder_t;
typedef struct pgp_writer_stack *pgp_writer_stack_t;
@@ -494,7 +494,7 @@ typedef enum pgp_verification_result_variant {
typedef pgp_status_t (*pgp_decryptor_get_public_keys_cb_t) (void *,
pgp_keyid_t *, size_t,
- pgp_tpk_t **, size_t *,
+ pgp_cert_t **, size_t *,
void (**free)(void *));
typedef pgp_status_t (pgp_decryptor_do_decrypt_cb_t) (
@@ -374,28 +374,28 @@ typedef struct pgp_user_id_binding *pgp_user_id_binding_t;
typedef struct pgp_user_id_binding_iter *pgp_user_id_binding_iter_t;
/*/
-/// An iterator over keys in a TPK.
+/// An iterator over keys in a Cert.
/*/
@@ -374,28 +374,28 @@ typedef struct pgp_user_id_binding *pgp_user_id_binding_t;
///
-/// A `TPKParser` parses a keyring, which is simply zero or more
-/// binary TPKs concatenated together.
+/// A `CertParser` parses a keyring, which is simply zero or more
+/// binary Certs concatenated together.
/*/